@@ -28,6 +28,7 @@ from os import path
 
 from qubesadmin import exc
 from qubesadmin import utils
+from qubesadmin.tools import qvm_start
 
 # pylint: disable=import-error
 from PyQt5.QtCore import (Qt, QAbstractTableModel, QObject, pyqtSlot, QEvent,
@@ -46,7 +47,6 @@ from qubesmanager.about import AboutDialog
 
 from . import ui_qubemanager  # pylint: disable=no-name-in-module
 from . import settings
-from . import global_settings
 from . import restore
 from . import backup
 from . import create_new_vm
@@ -637,7 +637,7 @@ class UpdateVMThread(common_threads.QubesThread):
                         pass
                 self.vm.run_service("qubes.InstallUpdatesGUI",
                                     user="root", wait=False)
-        except (ChildProcessError, subprocess.CalledProcessError,
+        except (OSError, subprocess.SubprocessError,
                 exc.QubesException) as ex:
             self.msg = (self.tr("Error on qube update!"), str(ex))
 
@@ -671,12 +671,15 @@ class QubesProxyModel(QSortFilterProxyModel):
 
     # pylint: disable=too-many-return-statements
     def filterAcceptsRow(self, sourceRow, sourceParent):
-        if self.window.show_all.isChecked():
-            return super().filterAcceptsRow(sourceRow, sourceParent)
-
         index = self.sourceModel().index(sourceRow, 0, sourceParent)
         vm = self.sourceModel().data(index, Qt.UserRole)
 
+        # if hide internal is true, ignore all other filters
+        if not self.window.show_internal_action.isChecked() and vm.internal:
+            return False
+        if self.window.show_all.isChecked():
+            return super().filterAcceptsRow(sourceRow, sourceParent)
+
         if self.window.show_running.isChecked() and \
                 vm.state['power'] != 'Halted':
             return super().filterAcceptsRow(sourceRow, sourceParent)
@@ -748,6 +751,33 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
         self.fill_cache()
         self.qubes_model = QubesTableModel(self.qubes_cache)
 
+        self.show_running.stateChanged.connect(self.invalidate)
+        self.show_halted.stateChanged.connect(self.invalidate)
+        self.show_network.stateChanged.connect(self.invalidate)
+        self.show_templates.stateChanged.connect(self.invalidate)
+        self.show_standalone.stateChanged.connect(self.invalidate)
+        self.show_all.stateChanged.connect(self.invalidate)
+
+        # Create view menu
+        for col_no, column in enumerate(self.qubes_model.columns_indices):
+            action = self.menu_view.addAction(column)
+            action.setData(column)
+            action.setCheckable(True)
+            action.toggled.connect(partial(self.showhide_column, col_no))
+
+        self.menu_view.addSeparator()
+        self.show_internal_action = self.menu_view.addAction(
+            self.tr('Show internal qubes'))
+        self.show_internal_action.setCheckable(True)
+        self.show_internal_action.toggled.connect(self.invalidate)
+
+        self.menu_view.addSeparator()
+        self.menu_view.addAction(self.action_toolbar)
+        self.menu_view.addAction(self.action_menubar)
+
+        self.menu_view.addSeparator()
+        self.menu_view.addAction(self.action_compact_view)
+
         self.proxy = QubesProxyModel(self)
         self.proxy.setSourceModel(self.qubes_model)
         self.proxy.setSortRole(Qt.UserRole + 1)
@@ -758,13 +788,6 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
         self.proxy.layoutChanged.connect(self.update_template_menu)
         self.proxy.layoutChanged.connect(self.update_network_menu)
 
-        self.show_running.stateChanged.connect(self.invalidate)
-        self.show_halted.stateChanged.connect(self.invalidate)
-        self.show_network.stateChanged.connect(self.invalidate)
-        self.show_templates.stateChanged.connect(self.invalidate)
-        self.show_standalone.stateChanged.connect(self.invalidate)
-        self.show_all.stateChanged.connect(self.invalidate)
-
         self.table.setModel(self.proxy)
         self.table.setItemDelegateForColumn(3, StateIconDelegate())
         self.table.resizeColumnsToContents()
@@ -774,19 +797,6 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
         self.table.setContextMenuPolicy(Qt.CustomContextMenu)
         self.table.customContextMenuRequested.connect(self.open_context_menu)
 
-        # Create view menu
-        for col_no, column in enumerate(self.qubes_model.columns_indices):
-            action = self.menu_view.addAction(column)
-            action.setData(column)
-            action.setCheckable(True)
-            action.toggled.connect(partial(self.showhide_column, col_no))
-
-        self.menu_view.addSeparator()
-        self.menu_view.addAction(self.action_toolbar)
-        self.menu_view.addAction(self.action_menubar)
-        self.menu_view.addSeparator()
-        self.menu_view.addAction(self.action_compact_view)
-
         try:
             self.load_manager_settings()
         except Exception as ex:  # pylint: disable=broad-except
@@ -854,14 +864,13 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
             for info in selected_vms:
                 try:
                     info.vm.template = template
-                except exc.QubesValueError as ex:
+                except exc.QubesException as ex:
                     errors.append((info.name, str(ex)))
 
             for error in errors:
                 QMessageBox.warning(self, self.tr("{0} template change failed!")
                         .format(error[0]), error[1])
 
-
     def change_network(self, netvm_name):
         selected_vms = self.get_selected_vms()
         reply = QMessageBox.question(
@@ -874,10 +883,13 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
         if reply != QMessageBox.Yes:
             return
 
-        if netvm_name not in [None, 'default']:
+        if netvm_name:
             check_power = any(info.state['power'] == 'Running' for info
                     in self.get_selected_vms())
-            netvm = self.qubes_cache.get_vm(name=netvm_name)
+            if netvm_name == 'default':
+                netvm = self._get_default_netvm()
+            else:
+                netvm = self.qubes_cache.get_vm(name=netvm_name)
             if check_power and netvm.state['power'] != 'Running':
                 reply = QMessageBox.question(
                     self, self.tr("Qube Start Confirmation"),
@@ -941,6 +953,8 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
                 self.show_templates.isChecked())
         self.manager_settings.setValue('show/standalone',
                 self.show_standalone.isChecked())
+        self.manager_settings.setValue('show/internal',
+                self.show_internal_action.isChecked())
         self.manager_settings.setValue('show/all', self.show_all.isChecked())
 
     def save_sorting(self):
@@ -1152,6 +1166,8 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
         self.show_all.setChecked(self.manager_settings.value(
             'show/all', "true") == "true")
 
+        self.show_internal_action.setChecked(self.manager_settings.value(
+            'show/internal', "false") == "true")
         # load last window size
         self.resize(self.manager_settings.value("window_size",
                                                 QSize(1100, 600)))
@@ -1390,10 +1406,18 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
 
     # noinspection PyArgumentList
     @pyqtSlot(name='on_action_startvm_tools_install_triggered')
-    # TODO: replace with boot from device
+    # TODO: unhardcode path
     def action_startvm_tools_install_triggered(self):
         # pylint: disable=invalid-name
-        pass
+        if not path.exists(r'/usr/lib/qubes/qubes-windows-tools.iso'):
+            QMessageBox.warning(
+                    self,
+                    self.tr("QWT not found"),
+                    self.tr("'qubes-windows-tools' is not installed in dom0."))
+        for vm_info in self.get_selected_vms():
+            vm = vm_info.vm
+            qvm_start.main(['--cdrom',
+                'dom0:/usr/lib/qubes/qubes-windows-tools.iso', vm.name])
 
     @pyqtSlot(name='on_action_pausevm_triggered')
     def action_pausevm_triggered(self):
@@ -1638,13 +1662,7 @@ class VmManagerWindow(ui_qubemanager.Ui_VmManagerWindow, QMainWindow):
     # noinspection PyArgumentList
     @pyqtSlot(name='on_action_global_settings_triggered')
     def action_global_settings_triggered(self):  # pylint: disable=invalid-name
-        with common_threads.busy_cursor():
-            global_settings_window = global_settings.GlobalSettingsWindow(
-                self.qt_app,
-                self.qubes_app,
-                self)
-        global_settings_window.show()
-        self.settings_windows['global_settings_window'] = global_settings_window
+        subprocess.check_call('qubes-global-config')
 
     # noinspection PyArgumentList
     @pyqtSlot(name='on_action_manage_templates_triggered')
